WAMP XBR Decentralized Messaging Extension
==========================================

|PyPI| |Python| |CI| |Docs| |License| |Downloads|

.. |PyPI| image:: https://img.shields.io/pypi/v/xbr.svg
   :target: https://pypi.python.org/pypi/xbr
.. |Python| image:: https://img.shields.io/pypi/pyversions/xbr.svg
   :target: https://pypi.python.org/pypi/xbr
.. |CI| image:: https://github.com/wamp-proto/wamp-xbr/workflows/main/badge.svg
   :target: https://github.com/wamp-proto/wamp-xbr/actions?query=workflow%3Amain
.. |Docs| image:: https://readthedocs.org/projects/xbr/badge/?version=latest
   :target: https://xbr.readthedocs.io/en/latest/
.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/wamp-proto/wamp-xbr/blob/master/LICENSE
.. |Downloads| image:: https://img.shields.io/pypi/dm/xbr.svg
   :target: https://pypi.python.org/pypi/xbr

--------------

**XBR** enables secure decentralized application messaging, peer-to-peer data-trading
and -service microtransactions in open data markets between multiple independent
entities or operators.

XBR sits on top of `WAMP <https://wamp-proto.org>`__, an open messaging middleware
and service mesh technology, enabling secure integration, trusted sharing and
monetization of data and data-driven microservices between different parties.

The protocol is implemented in *smart contracts* written in
`Solidity <https://solidity.readthedocs.io>`__ for the
`Ethereum blockchain <https://ethereum.org/>`__, and is
`MIT <https://github.com/wamp-proto/wamp-xbr/blob/master/LICENSE>`__ licensed.


Contents
--------

.. toctree::
   :maxdepth: 2

   overview
   installation
   getting-started
   programming-guide/index
   releases
   changelog
   contributing
   OVERVIEW.md
   ai/index

--------------

*Copyright (c) typedef int GmbH. Licensed under the* `MIT License <https://github.com/wamp-proto/wamp-xbr/blob/master/LICENSE>`__.
*WAMP, Autobahn, Crossbar.io and XBR are trademarks of typedef int GmbH (Germany).*
